#!/bin/sh

#########################################################################################
#@***h* Daily OLR CDR/OLR_gridder2b.sh
# 
# NAME
#     OLR_gridder2b.sh
#
# USAGE 
# 	   OLR_gridder.sh  $satid $yyyy $mm $dd $yday
#
# PURPOSE
#  	Grid the OLR retrievals at fov to 1x1 hourly maps
#     OLR fov retrieval files are scanned and passed to grid_olr_1deg_hrly.f90 for each satellite 
#
# DESCRIPTION
# 		This script performs 1x1 deg hourly maps gridding
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# Language: Bourne shell
# 
# INPUT
#  	<work>/OLR_fov/<satid>/<yyyy>/ - OLR retrievals swath file (ie., at FOV level)
# 
# OUTPUT
#  	<work>/Hourly/OLR_hourly_mean_<satid>_<yyyy><ddd>.dat - Hourly mean OLR for a given satellite
#  	<work>/Hourly/ECT_hourly_mean_<satid>_<yyyy><ddd>.dat - Hourly mean ECT for a given satellite
#
# HISTORY
#  	2013-09-12	Hai-Tien Lee. 
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

satid=$1
yyyy=$2
mm=$3
dd0=$4
yday=$5

target_day=$yyyy$mm$dd0
yday_target=$yday
yy=`echo $target_day | cut -c3-4`

stamp_target_day=$yy$yday

src='HIRS_OLR_CDR_home'
work='HIRS_OLR_CDR_work'

# OLR fov retrieval directory
OLR_fov="$work/OLR_fov"
Hourly="$work/Hourly"
mkdir -p $Hourly/$yyyy

# Construct file list 
list_file=List_OLR_fov_${satid}_${yyyy}d${yday}.dat

if test -r $list_file
then
rm $list_file
fi
files=`ls $OLR_fov/$satid/$yyyy/*${stamp_target_day}* $OLR_fov/$satid/$yyyy/*/*${stamp_target_day}* 2> /dev/null` 
nfile=`echo $files | wc -w`

if test $nfile -eq 0
then
	echo "*** $satid ${stamp_target_day} fov file does not exist. Gridder2 Exited."
    exit
fi

# Clean up before run
if test -r OLR_monthly_mean.dat
then
rm OLR_monthly_mean.dat
fi
if test -r ECT_monthly_mean.dat
then
rm ECT_monthly_mean.dat
fi

for file_day in $files
do
# calculate nrec. there are 5 variables per record, 4-byte each
nrec=`wc -c $file_day | awk '{print $1/5/4}'`
echo $file_day >> $list_file
echo $nrec >> $list_file
done
cat $list_file

# execute grid_olr_1deg_hrly.exe
if test $nrec -ge 500000
then
$src/Codes/Gridder_v2b/grid_olr_1deg_hrly.exe << EOF
$file_day
$nrec
EOF
fi


# Archive
mv $list_file $Hourly/$yyyy
mv OLR_hourly_mean.dat $Hourly/$yyyy/OLR_hourly_mean_${satid}_${yyyy}d${yday}.dat
mv ECT_hourly_mean.dat $Hourly/$yyyy/ECT_hourly_mean_${satid}_${yyyy}d${yday}.dat



exit


