!========================================================================================
!@***h* Daily OLR CDR/brightn.f90
! 
! NAME         
!   brightn.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/, xx=05,06, ...,21
!
! PURPOSE
!   Calculate Brightness temperature (deg K) for given radiance (mW m-2 (cm-1 sr)-1)
!
! DESCRIPTION
!   This F90 subroutine Calculate Brightness temperature (deg K) for given 
!	radiance (mW m-2 (cm-1 sr)-1).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!	instrument.cmn.f90
!	phys_const.cmn.f90
!
! INPUTS
!   r - radiance (mW m-2 (cm-1 sr)-1)
!   k - HIRS channel number (1-19)
!
! OUTPUTS
!   return brightness temperature (deg K)
!
! HISTORY
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

      function brightn(r,k)

      include 'instrument.cmn.f90'
      include 'phys_const.cmn.f90'

      wv=waven(k)
      expn=c1*wv*wv*wv/r+1.
      brightn=c2*wv/alog(expn)
      return 
      end
