!========================================================================================
!@***h* Daily OLR CDR/read_instru_para.f90
! 
! NAME         
!   read_instru_para.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/, xx=05,06,07,08,09,10,11,12,14
!
! PURPOSE
!   Performs HIRS radiance calibration
!
! DESCRIPTION
!   This F90 subroutine reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!	instrument.cmn.f90
!
! INPUTS
!   pred_cali.txt - Static data file containing predicting coefficients for temperature-dependent
!	                interpolation for calibration coefficients 
!	prt.txt - Coefficients to derive temperatures for PRT sensors
!	band.txt - band parameters, for apparent to effective brightness temperature conversion
!	Note that these three file names are hard coded. They are created as symbolic links in
!	the calling script.
!
! OUTPUTS
!
! HISTORY
!   2009-01-01   Junsuk Lee modified for NOAA-KLM level-1b data format
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

      subroutine read_instru_para

      include 'instrument.cmn.f90'
      real*4 a(4),x

! lee moved from newhirscali to here
! read in coefficients for predicting calibration coefficients    
      open(11,file='pred_cali.txt',status='old')
      read(11,*)
      do k=1,19
       read(11,*) coslope(:,k)
      enddo
      read(11,*)
      do k=1,19
       read(11,*) cointcpt(:,k)
      enddo
      close(11)
! read in IWT PRT Count to Temperature coefficients
      open(12,form='formatted',status='old',file='prt.txt')
      do i=1,4
         read(12,*) x,cofw(:,i)
      enddo
      close(12)

      open(13,form='formatted',status='old',file='band.txt')
      do i=1,19 
         read(13,*) a
         waven(i)=a(2)
         bandc(1,i)=a(3)
         bandc(2,i)=a(4)
      enddo
      close(13)

      return
      end
