!========================================================================================
!@***h* Daily OLR CDR/OLR_retrieval.f90
! 
! NAME         
!   OLR_retrieval.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=15, 16, ...,20
!
! PURPOSE
!   Performs HIRS radiance calibration and OLR retrieval
!
! DESCRIPTION
!   This program reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998) and perform OLR retrieval 
!   using Ellingson et al. (1989, 1994) method.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  swapbyte.f90
!	read_instru_para.f90
!	rdhdr.f90
!	read_hirs1b.f90
!	get_hirs.f90
!	calc_olr.f90
!
! INPUTS
!
! OUTPUTS
!
! HISTORY
!   2003-01-01   Original Code (atovmain.f) obtained from L. McMillin
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

        program OLR_retrieval

!   This program will be used to process the NOAA KLM Hirs3's processing    Mar.,2002

        USE type_def
        Implicit None
        include 'superdata.cmn.f90'
        include 'instrument.cmn.f90'

        Type(struc_1b) hirs1b
        Type(struc_1b) defhirs

        integer, parameter:: nvar = 7
        integer, dimension(20):: &
        lookup=(/1,17,2,3,13,4,18,11,19,7,8,20,10,  &
                         14,6,5,15,12,16,9 /)
        Integer ll
        integer,dimension(20):: &
             ILookup=(/1,3,4,6,16,15,10,11,20,13,8,18,5,  &
             14,17,19,2,7,9,12 /)   
        Real Slope(20,2),Intercept(20,2)

        Real Cal(0:2,20)
        Real factor(0:2)
        Data Factor / 1.0e-12 , 1.0e-9, 1.0e-6/

        Integer Ichan,Ispot,Knt,Len,i,j,k

        Integer Scantype
        Integer CalProblem
        Integer CalTest
        Integer QualProblem
        Integer QualTest
        Integer CalKnt
        Integer TooEarly
        Integer Datafill

        Logical First

        Integer Jdate

        Integer Ip

!variables added                                     jzhao
        integer hunit,nrec,funit,ounit,lenRec,isup
        integer*2 stid,idttp,starty,startd,enddy,numscan,numrec
        integer*4 startt,endt,fsttime
        integer*4 iis,iiw,crec,oriCali(3,20)
        integer iexp, idiff,iss,isact,iirec,iln
        integer satid
        real olr_coeff(nvar+1,6500)
        character*120 olr_coeff_file, data1b_list


        integer*2 aaa, bbb, ccc, eee, fff                      !jlee
        integer*4 ddd
        integer*2 nerror
        integer*2 yday_target

!************************************************************************
        Character*255 filen, nameout  ! 1b file name
        Integer:: context=0                      ! ditto

        Integer Start,End
        Integer iclr

        Real Rad,Tb,Tbright

        Integer Jchan
        Real FK1,FK2

!************************************************************************

! read instrument parameters
        call read_instru_para

!   initialize the added variables

        Qualproblem = 0
        calProblem = 0
        CalKnt = 0
        Knt = 0
!        defhirs = -9999
! 2011.3.17 Hai-Tien
! Assign missing value to defhirs radiance count for all elements (58x20)
! This missing value will enable get_hirs.f90 to skip calibrating the bad observations.
        do i=1,58
        do j=1,20
        	  defhirs%ele(i)%rCount(j)=-9999
        enddo
        enddo

        crec=1   !the rec number of output count data

        read(5,*) satid
        read(5,'(a120)') data1b_list
        read(5,'(a120)') olr_coeff_file
        read(5,'(a120)') nameout
        read(5,*) yday_target

        write(6,*) satid
        write(6,*) 'data1b_list is',data1b_list
        write(6,*) nameout
        write(6,*) 'Target yday=',yday_target
        
        open(20,file=olr_coeff_file)
        read(20,*) olr_coeff
        close(20)

!open a file which contains the file names
        funit=111
        open(funit,file=data1b_list,status='old')
!        open(333,file=nameout,status='unknown')
        open(334,file=nameout,status='unknown', &
             form='unformatted',access='direct',recl=20)

!        open(335,file=nameout_rad,status='unknown', &
!             form='unformatted',access='direct',recl=16)
!

        Do While (.true.)  !  orbit file loop

          read(funit,'(a100)',end=400)filen
          Write(6,*) 'Processing file ',filen

          hunit=1
          nrec=1  !first one is head record
          Open(hunit, file=filen,form='unformatted', &          
               status='old',access='direct',recl=4608)

        First = .true.

        call rdhdr(hunit,idttp,numscan,numrec,starty,startd,   &
           startt,endt ,stid) 
      print *,'head info'
      print *,'spacecraft id ',stid
      print *,'data type ',idttp
      print *,'number of recorder',numrec
      print *,'number of scan',numscan
      print *,'Start of data year,day,time ',starty,startd,startt
      print *,'End of the data',endt

 5100 isup =0

         nrec=nrec+1
         nerror=0
          print *, 'nrec = ', nrec

          call read_hirs1b(nrec,filen,hirs1b,nerror)

          print *, nerror
          if (nerror .eq. 300) goto 300


!org         Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b

!         Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b%scanNum, &
!         hirs1b%scanYr, hirs1b%scanDay, hirs1b%clockDrift, &
!         hirs1b%scanTime, hirs1b%byte13, hirs1b%frameNum, &
!         hirs1b%ScanPos, hirs1b%scanType



         print *,'scan num',hirs1b%scanNum
         print *,'scanYr',hirs1b%scanYr
         print *,'scanDay',hirs1b%scanDay
         print *,'scanTime',hirs1b%scanTime
         print *,'frameNum',hirs1b%frameNum
         print *,'scanType',hirs1b%scanType
         print *,'location',hirs1b%location/10.0e4
         print *,'wtts1',hirs1b%wtts1
         print *,'lineCount',hirs1b%lineCount
         print *,'instrument temp',hirs1b%instTemp
         print *,'count',hirs1b%ele(56)%rCount


!      aaa = hirs1b%scanNum
!      bbb = hirs1b%scanYr
!      ccc = hirs1b%scanDay
!      ddd = hirs1b%scanTime
!      eee = hirs1b%frameNum
!      fff = hirs1b%scanType
   

!      print *, aaa, bbb, ccc, ddd, eee, fff  

!      call swapbyte(aaa)
!      call swapbyte(bbb)
!      call swapbyte(ccc)
!      call swapbyte(ddd)
!      call swapbyte(eee)
!      call swapbyte(fff)


!      print *, aaa, bbb, ccc, ddd, eee, fff  


!      if (nrec .eq. 1050) stop


  
      if(hirs1b%scanType .ne. 1)  then
         go to 5100  ! start from a space view
      endif
   
      fsttime = hirs1b%scanTime
      iis=1
      suphirs(1)=hirs1b
  ! suppose to read the warm blackboby records
         nrec=nrec+1
          call read_hirs1b(nrec,filen,hirs1b,nerror)
          if (nerror .eq. 300) goto 300

!j         Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b
         if (hirs1b%scanType .ne. 3) then
            print *, 'Not warm blackbody scan!'
            go to 5100  ! start from a space view
         endif 

         suphirs(2)=hirs1b

!    set expected scaline 
      iexp = hirs1b%scanNum + 1

!  do loop 350 processes superswath 1 to 30 (usually #S.S <26)
      do 350 iis=1,30

! if not the contingent superswath then assign the last superswath's
! last 3 line as the first 3 line of new swath
      if( isup .ne. 0) then 
	    suphirs(1)= suphirs(41)
	    suphirs(2)= suphirs(42)
      endif
! pull out the time of the 1st line for gtmsun to use
      fsttime = suphirs(1)%scanTime

!do loop 330 processes 40 lines of the superswath
      idiff=0
      do 330 iss=3,40   !from first earth view to last earth view 
      if (idiff .gt. 0) go to 320
 5500 nrec=nrec+1
          call read_hirs1b(nrec,filen,hirs1b,nerror)
          if (nerror .eq. 300) goto 300

!j      Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b
      isact =  hirs1b%scanNum
!   check whether a gap in the data
      if (isact .gt. iexp) then
         print *, 'There is a gap between scan lines!' ,isact,iexp
!         if (iexp .eq. numrec) goto 300

         idiff=isact - iexp
         if(idiff .gt. 10) go to 5100
         suphirs(iss+idiff) = hirs1b
         go to 320
      else if (isact .lt. iexp) then
         go  to 5500
      endif

      suphirs(iss) = hirs1b

      goto 328
    
 320  suphirs(iss)= defhirs
      idiff=idiff-1

 328	iexp =hirs1b%scanNum +1
 330	continue

! continue to read the next calibration part
         nrec=nrec+1
          call read_hirs1b(nrec,filen,hirs1b,nerror)
          if (nerror .eq. 300) goto 300

!j         Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b
      isact=hirs1b%scanNum

!      print * , 'scanline=', isact

!   check whether a gap in the data
      if (isact .ne. iexp) then
      print *, 'There is a gap between scan lines!'
      print *, 'Pay attention to the falg of the scan!!'
      endif

      if(hirs1b%scanType .ne. 1)  then
      print *, 'Not the space line? Go back for a new super swath!'
      go to 5100
      endif

!   if really a space view 
      suphirs(41) = hirs1b

! suppose to read the warm blackboby records
         nrec=nrec+1
          call read_hirs1b(nrec,filen,hirs1b,nerror)
          if (nerror .eq. 300) goto 300

!         Read(hunit,rec=nrec,err=300,IOstat=Istat) hirs1b
         if ( hirs1b%scanType .ne. 3) then
            print *, 'Not warm blackbody scan! Not a valid superswath!'
            print *, 'Start to find a new super swath!!'
            go to 5100  ! start from a space view
         endif 
         suphirs(42)= hirs1b
     
! set a new isexp ........
      iexp = hirs1b%scanNum+1
      isup=isup+1
      print * , '#',isup, '   superswath'


!...   process hirs dat
      iirec = iirec+1
      call get_hirs

!   finish the Hirs super swath
!   Now try to get the corresponding AMSU superswath
!      print *, 'time for hirs:', fsthr,fstmn,fstsec
!c      call gtamsu(fsthr,fstmn,fstsec)
!c      if (msufal.ne.0) go to 350   !jump to next S.S


! output AMSU data for analysis
!        write(222)iirec
!	write(222)(((amsudat(i,j,k),i=1,12),j=1,11),k=1,10) 


!c  230 if (irfail.eq.0.or.msufal.eq.0) iswfal=0

!c      if(mrain .eq. 1) irain=1

! matchup hirs scan with interpolated msu scan   

!c      call intamsu(msudat,msui,1,40)

! put msui into hirsdat
!c	do ichan=1,4
 !c         do ispot=1,56
 !c           do iln=1,40
!c	   hirsdat(28+ichan,ispot,iln)=msui(ichan,ispot,iln)
!c           if (msui(ichan,ispot,iln) .le. -9999) then
!c           hirsdat(1,ispot,iln)=-2.0
!c           endif
!c	   enddo
!c	  enddo
!c	enddo

! output the data
!        print *, 'OUTPUT:', (hirsdat(i,25,5),i=1,35)
!        iirec=iirec+1

!c        write(333)iirec
!C	   write(333,rec=iirec)(((hirsdat(i,j,k),i=1,35),j=1,56),k=1,40) 
!      write(6,*) 'IIREC=',iirec
!C	   write(333,*) hirsdat

      call calc_olr(satid,olr_coeff,crec,yday_target)

  350 continue	

  300   nerror=0
        Continue 

        Close(hunit)
        EndDo ! orbit file loop

  400   Continue

        Close(funit)
!        Close(333)
        Close(334)
!        Close(335)
        close(555)
        close(666)

        Stop

  310   Continue
        Write(6,*) 'Read error ',nerror
        Stop
        End
        
