!========================================================================================
!@***h* Daily OLR CDR/rdhdr.f90
! 
! NAME         
!   rdhdr.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx, xx=15,16,...,21
!
! PURPOSE
!   Read header info from HIRS level-1b data
!
! DESCRIPTION
!   This F90 subroutine reads header info in HIRS Level-1b data.
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!  	swapbyte.f90
!  	swapwd.f90
!
! INPUTS
!   hdbuf - one header record of HIRS level 1b data read in from file unit 'in'.
!
! OUTPUTS
!   stid - satellite id
!	idttp -
!	numscan - number of scan lines in this orbit file
!	numrec - number of record in this orbit file
!	starty - beginning year
!	startd - beginning day of the year
!	startt - beginning time of the day (seconds)
!	endt - ending time of the day 
!	
! HISTORY
!   2003-01-01   Original Code (atovmain.f) obtained from L. McMillin
!   2003-08-26   Hai-Tien Lee for NOAA-KLM
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

subroutine rdhdr(in,idttp,numscan,numrec,starty,startd,   &
           startt,endt ,stid)

      implicit none
      integer in,i
      integer*2 numhead,stid,idttp,starty,startd,endy,endd
      integer*4 startt,endt,wd1,wd2
      integer*2 numrec,numscan
      character*42 dataname
      integer*2 hdbuf(2304)
      equivalence(wd1,hdbuf(45))
      equivalence(wd2,hdbuf(51))
      equivalence(dataname,hdbuf(12))

      read(in,rec=1) hdbuf

      numhead=hdbuf(8)
      print *,'number of head records is ',numhead
      
 !swap the bytes for the file name string
      do i = 12,32
         call swapbyte(hdbuf(i))
      enddo
      print *,'name of the data set is ' ,dataname


      stid=hdbuf(37)
      idttp=hdbuf(39)
!      print *,'stid & dattyp',stid,hdbuf(37),idttp,hdbuf(39)

      starty=hdbuf(43)
      startd=hdbuf(44)
      endy=hdbuf(49)
      endd=hdbuf(50)
      print* ,'end date is',endy,endd


      call swapwd(hdbuf(45),hdbuf(46))
      call swapwd(hdbuf(51),hdbuf(52))
      print*,wd1,wd2
      
      startt=wd1
      endt=wd2

      numrec=hdbuf(65)
      numscan=hdbuf(66)      

      print*, numrec,numscan



      return                                                            
      end                                                               
