!========================================================================================
!@***h* Daily OLR CDR/type_def.f90
! 
! NAME         
!   type_def.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/, xx=15,16,...,21
!
! PURPOSE
!   Define the structure of the Hirs leve-1b data
!
! DESCRIPTION
!   This F90 module defines HIRS level-1b data as a structure. Structure definition is satellite-
!	dependent and time dependent (as format changes).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!
! INPUTS
!
! OUTPUTS
!
! HISTORY
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

! This sub program is used to define the structure of the 
! Hirs 1b data set

MODULE type_def
implicit none

Type hirsElem
sequence
!structure for an element(frame?) 
integer*4 headElem
integer*2 rCount ( 20 )
integer*2 flagElem
integer*2 zeroFill
End Type hirsElem


Type struc_1b
sequence
!structure for the data of a complete 1b scan 
integer*2 scanNum
integer*2 scanYr
integer*2 scanDay
integer*2 clockDrift
integer*4 scanTime
integer*2 byte13
integer*2 frameNum
integer*2 scanPos
integer*2 scanType
integer*4 byte21 ( 02 )
integer*4 qualField
integer*4 scanQual
integer*2 calQual ( 20 )
character  frameQual ( 64 )
integer*4 byte141 ( 04 )
!calibration data part
!**scales
integer*4 PrimCali ( 03 , 20 )
integer*4 SpareCali ( 03 , 20 )
integer*4 byte637 ( 03 )
!navigation data part
character byte649 ( 14 )
!**scales
integer*2 height
integer*2 angles ( 03 , 56 )
integer*4 location ( 02 , 56 )
integer*4 byte1449 ( 02 )
Type(hirsElem) ele ( 58 )   !element 0-57
!frame 58
integer*4 head58
integer*2 wtts1 ( 05 )
integer*2 wtts2 ( 05 )
integer*2 wtts3 ( 05 )
integer*2 wtts4 ( 05 )
integer*2 flag58
integer*2 byte4287
integer*4 head59
integer*2 space1 ( 05 )
integer*2 space2 ( 05 )
integer*2 space3 ( 05 )
integer*2 space4 ( 05 )
integer*2 flag59
integer*2 byte4335
Type(hirsElem)  ele60 ( 02 )     !element 60-61
integer*4 head62
integer*2 instTemp ( 08 )
character byte4453 ( 14 )
integer*4 head63
integer*2 lineCount
integer*2 byte4487 ( 27 )
!character byte4541 ( 4608-4541+1 )
character byte4541 ( 68 )

END Type struc_1b

END MODULE type_def
