!========================================================================================
!@***h* Daily OLR CDR/read_instru_para_HIRS4.f90
! 
! NAME         
!   read_instru_para_HIRS4.f90
!
! LOCATION         
!   Codes/OLR_retrieval/Nxx/, xx=18,19,20
!
! PURPOSE
!   Performs HIRS radiance calibration
!
! DESCRIPTION
!   This F90 subroutine reads in HIRS Level-1b data, performs HIRS radiance calibration
!	using McMillin method (NOAA POES Users Guide, 1998).
!
! AUTHOR
!   Hai-Tien Lee
!
! COPYRIGHT	
!   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
!   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
!   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
!   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
!   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
!   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
!   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
!   SUPPORT TO USERS.
!
! EXTERNALS
!
! DEPENDENCIES
!	instrument.cmn.f90
!
! INPUTS
!   pred_cali.txt - Static data file containing predicting coefficients for temperature-dependent
!	                interpolation for calibration coefficients 
!	prt.txt - Coefficients to derive temperatures for PRT sensors
!	band.txt - band parameters, for apparent to effective brightness temperature conversion
!	Note that these three file names are hard coded. They are created as symbolic links in
!	the calling script.
!
! OUTPUTS
!
! HISTORY
!   2009-01-01   Junsuk Lee modified for NOAA-KLM level-1b data format
!   2010-11-26   Hai-Tien Lee for NCDC HIRS OLR CDR Production
!   2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
!
!@*****
!========================================================================================

! Changes from N15
!The number of warm target changed from 4 to 5.
!'space(3)' becomes 'wtts5(5)'

!1. Change type of array of mean
!'hirs_cali.f90'

!1) integer*2 scount(56,20), wcount(56,20), warmt(20) ---> real*4 scount(56,20), wcount(56,20), warmt(25)

!2. Change number of warm count from 4 to 5
!'hirs_cali.f90'

!1) real*4 prtw(4)  --->  prtw(5)

!2) warmt(20)   --->   warmt(25)

!3) add line
!   warmt(21:25)  =  onehir%space3

!4) do 130 i=1,4   --->   do 130 i=1,5

!5) tprtw = tprtw / 4.0   --->   tprtw = tprtw / 5.0

!6) 'instrument.cmn.f90'
!real*4 cofw(5,4)   --->   real*4 cofw(5,5)

!7) 'read_intru_para.f90'
!do i=1,4   --->   do i=1,5

!3. number of data in 'prt.txt' changed.
!please check 'n18_prt.dat'
!2 more columns are added.



!***********************************************************************************



      subroutine read_instru_para

      include 'instrument.cmn.f90'
 
!C read in coefficients for predicting calibration coefficients    
      open(11,file='pred_cali.txt',status='old')
      read(11,*)
      do k=1,19
       read(11,*) coslope(:,k)
      enddo
      read(11,*)
      do k=1,19
       read(11,*) cointcpt(:,k)
      enddo
      close(11)

      open(12,form='formatted',status='old',file='prt.txt')
      do i=1,5
         read(12,*) no_prt(i), cofw(:,i)
      enddo
      close(12)
!      print *, 'cofw',cofw(1:6,1)

      open(13,form='formatted',status='old',file='band.txt')
      do k=1,19
         read(13,*)i,waven(k),bandc(1,k),bandc(2,k)
      enddo
      close(13)

      return
      end
