#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/Compile_touch.sh
# 
# NAME
#     Compile_touch.sh
#
# PURPOSE
# 		Prepare executables used in OLR CDR Production
#
# DESCRIPTION
# 		This script calls the individual makefile to prepare all the executables.
#     Only touch those have been modified.
#
# USAGE
#     Compile.sh
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
# 
# HISTORY
#  	2011-03-07	Hai-Tien Lee. 
#     2011-03-27  Hai-Tien Lee, Add compilation of N05-N14 OLR_retrieval codes
#     2013-11-20  Hai-Tien Lee, Add N21
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

# User configurable ------------------------------------------------

# USAGE Compile_outch.sh "Production_Home_directory"

if [ $# -eq 0 ]
then
echo Error: Direcotry argument not provided.
echo Usage: Compile_outch.sh "Production_Home_directory"
exit
fi

# Production_home=/Garden/Hai-Tien/OLR_CDR/HIRS_OLR_CDR_Production
Production_home=$1
# ------------------------------------------------------------------

code_dir=$Production_home/Codes

# ---------------------------------------------------------
# OLR_retrieval
# ---------------------------------------------------------
cd $code_dir/OLR_retrieval

satids='N05 N06 N07 N08 N09 N10 N11 N12'
for satid in $satids
do
cd $satid
pwd
#make -f Makefile_HIRS2 clean
make -f Makefile_HIRS2
cd ..
done

satids='N11 N12 N14'
for satid in $satids
do
cd $satid
pwd
#make -f Makefile_HIRS2_1995 clean
make -f Makefile_HIRS2_1995
cd ..
done

satids='N15 N16 N17'
for satid in $satids
do
cd $satid
pwd
#make -f Makefile_HIRS3 clean
make -f Makefile_HIRS3
cd ..
done

satids='N18 N19 N20 N21'
for satid in $satids
do
cd $satid
pwd
#make -f Makefile_HIRS4 clean
make -f Makefile_HIRS4
cd ..
done

# ---------------------------------------------------------
# OLR_gridder
# ---------------------------------------------------------
cd $code_dir/Gridder_v2a
pwd
make clean
make

cd $code_dir/Gridder_v2b
pwd
make clean
make

# ---------------------------------------------------------
# Temporal
# ---------------------------------------------------------
cd $code_dir/Temporal
pwd
#make clean
make

# ---------------------------------------------------------
# NetCDF packer
# ---------------------------------------------------------
cd $code_dir/Packer
pwd
#make clean
make


echo =====================================================
echo Check compilation results: 
ls -l $code_dir/OLR_retrieval/N??/OLR_retrieval*.exe
ls -l $code_dir/Gridder/grid_olr.exe
ls -l $code_dir/Temporal/OLR_monthly_integral.exe
ls -l $code_dir/Packer/OLR_CDR_nc4_batch.exe
ls -l $utility_dir/parse_list_v3.exe
echo =====================================================


exit
