#!/bin/sh

#########################################################################################
#@***h* Daily OLR CDR/OLR_daily_integral.sh
# 
# NAME
#     OLR_Daily_integral.sh
#
# PURPOSE
#  	Giving the hourly maps from the available satellites, 
#	   perform daily mean integral with the blending processes.
#
# DESCRIPTION
# 		This script performs the blending and integral processes.
#
# USAGE 
# 	   OLR_integral_integral.sh $yyyy $mm $dd $intersat_ver
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# Language: Bourne shell
# 
# INPUT
#  	$work/Daily/OLR_Daily_mean_<satid>_<yyyy><mm>.dat - Daily mean OLR for a given satellite
#		$src/Data_static/coef_diurnal_model.dat
#		$src/Data_static/Intersat_Adjustment_Ed2.4.dat
# 
# OUTPUT
#  	$work/OLR_CDR/OLR_Daily_mean.<yyyy><mm>.dat
# 
# HISTORY
#  	2011-03-07	Hai-Tien Lee. 
#  	2013-03-21	Hai-Tien Lee. Pass intersat calibration version from calling program.
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################




### THIS IS A  SCRIPT TEMPLATE ###





# Temporal Integral for OLR Daily Mean
# 1. find available satellites
# 2. read in OLR and ECT
# 3. loop through all grids, integrate with diurnal model

yyyy=$1
mm=$2
dd0=$3

# 2013.3.21 Pass intersat_ver=Ed2.4 from calling program
intersat_ver=$4


src='HIRS_OLR_CDR_home'
work='HIRS_OLR_CDR_work'
Daily=$work/Daily

Daily=$work/Daily
CDR=$work/OLR_CDR

# Input
#    $Daily/OLR_Daily_mean_$satid.dat

# Output
#    $CDR/OLR_Daily_mean.$yyyy.$mm.dat


# Construct file list "List_OLR_Daily.dat"
input=List_OLR_Daily_$yyyy$mm.dat
if test -r $input
then
rm $input
fi

files_OLR=`ls $Daily/OLR_Daily_mean_???_$yyyy$mm.dat`
# files_ECT=`ls $Daily/ECT_Daily_mean_???.dat`

nsat=`echo $files_OLR | wc -w`

# Daily mean requires at least 15 days of observations
if test $nsat -le 0
then
	echo $Daily does not have any Daily maps. Stop.
	exit
else

 
echo $yyyy $mm $nsat > $input

echo $yyyy $mm $nsat

for file in $files_OLR
do
satid=`echo $file | sed -e 's/^.*\(...\)...........$/\1/'`
ect_file=$Daily/ECT_Daily_mean_${satid}_$yyyy$mm.dat
ect=`cat $ect_file`
echo $satid >> $input
echo $ect >> $input
echo $file >> $input
echo $satid $ect
done

# Clean up before run
if test -r OLR_Daily_mean.dat
then
rm OLR_Daily_mean.dat
fi

# Create a local copy of OLR diurnal model coefficients files
cp $src/Data_static/coef_diurnal_model.dat coef_diurnal_model.dat

# Create a local copy of Inter-satellite bias adjustment data file (Ed2.4 is hardcoded here)
cp $src/Data_static/Intersat_Adjustment_${intersat_ver}.dat Intersat_Adjustment.dat

cp $input List_OLR_Daily.dat
# execute OLR_Daily_mean_integral.exe
# prog=OLR_Daily_integral.exe
prog=OLR_Daily_integral_v2.4.exe

$src/Codes/Temporal/$prog

# Archive
mv OLR_Daily_mean.asc OLR_CDR/archive_ascii/OLR_Daily_mean_$yyyy$mm.asc
mv OLR_Daily_integral.log OLR_CDR/OLR_Daily_integral_$yyyy$mm.log
mv $input OLR_CDR/$input

fi
# nsat if test 




exit


exit


