#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/cal_date2.sh
# 
# NAME
#     distribute_codes.sh
#
# PURPOSE
# 		Calulate Date with or without offset
#
# DESCRIPTION
# 		This script calulates Date with or without offset, using 4-digit year
#
# USAGE
# 1. cal_date2.sh => returns today's date yyyymmdd
# 2. cal_date2.sh yyyy mm dd offset => returns the date offset from the given date
# 3. cal_date2.sh yyyymmdd offset => returns the date offset from the given date
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

# 2011.3.14 Hai-Tien Lee
# Calulate Date with or without offset
# Usage:
# 1. cal_date2 => returns today's date yyyymmdd
# 2. cal_date2 yyyy mm dd offset => returns the date offset from the given date
# 3. cal_date2 yyyymmdd offset => returns the date offset from the given date

if test $# -eq 4
then
   yyyy=$1
   mm=$2
   dd=$3
   offset=$4
elif test $# -eq 2
then
   yyyy=`echo $1 | cut -c1-4`
   mm=`echo $1 | cut -c5-6`
   dd=`echo $1 | cut -c7-8`
   offset=$2
elif test $# -eq 1
then
   yyyy=`date '+%Y'`
   mm=`date '+%m'`
   dd=`date '+%d'`
   offset=$1
else 
   yyyy=`date '+%Y'`
   mm=`date '+%m'`
   dd=`date '+%d'`
fi

if test $# -lt 1
then
   offset=0
else
   offset=`echo ${offset} | sed -e 's/+//g'`
fi

leap=`expr ${yyyy} \/ 4`
leap=`expr $leap \* 4`
l100=`expr ${yyyy} \/ 100`
l100=`expr $l100 \* 100`
if test ${yyyy} -eq $l100
then
   leap=`expr ${yyyy} \/ 400`
   leap=`expr $leap \* 400`
fi

if test ${yyyy} -eq $leap
then
   case $mm in
      1 | 01) total=`expr $dd + 0` ;;
      2 | 02) total=`expr 31 + $dd` ;;
      3 | 03) total=`expr 60 + $dd` ;;
      4 | 04) total=`expr 91 + $dd` ;;
      5 | 05) total=`expr 121 + $dd` ;;
      6 | 06) total=`expr 152 + $dd` ;;
      7 | 07) total=`expr 182 + $dd` ;;
      8 | 08) total=`expr 213 + $dd` ;;
      9 | 09) total=`expr 244 + $dd` ;;
      10) total=`expr 274 + $dd` ;;
      11) total=`expr 305 + $dd` ;;
      12) total=`expr 335 + $dd` ;;
   esac
else
   case $mm in
      1 | 01) total=`expr $dd + 0` ;;
      2 | 02) total=`expr 31 + $dd` ;;
      3 | 03) total=`expr 59 + $dd` ;;
      4 | 04) total=`expr 90 + $dd` ;;
      5 | 05) total=`expr 120 + $dd` ;;
      6 | 06) total=`expr 151 + $dd` ;;
      7 | 07) total=`expr 181 + $dd` ;;
      8 | 08) total=`expr 212 + $dd` ;;
      9 | 09) total=`expr 243 + $dd` ;;
      10) total=`expr 273 + $dd` ;;
      11) total=`expr 304 + $dd` ;;
      12) total=`expr 334 + $dd` ;;
   esac
fi

total=`expr $total + $offset`

if test $leap -ne ${yyyy}
then
  day_in_year=365
else
  day_in_year=366
fi

while test $total -gt $day_in_year
do
   total=`expr $total - $day_in_year`
   yyyy=`expr ${yyyy} + 1`
   leap=`expr ${yyyy} \/ 4`
   leap=`expr $leap \* 4`
   l100=`expr ${yyyy} \/ 100`
   l100=`expr $l100 \* 100`
   if test ${yyyy} -eq $l100
   then
      leap=`expr ${yyyy} \/ 400`
      leap=`expr $leap \* 400`
   fi
   if test $leap -ne ${yyyy}
   then
     day_in_year=365
   else
     day_in_year=366
   fi
done

while test $total -lt 1
do
   yyyy=`expr ${yyyy} - 1`
   leap=`expr ${yyyy} \/ 4`
   leap=`expr $leap \* 4`
   l100=`expr ${yyyy} \/ 100`
   l100=`expr $l100 \* 100`
   if test ${yyyy} -eq $l100
   then
      leap=`expr ${yyyy} \/ 400`
      leap=`expr $leap \* 400`
   fi
   if test $leap -ne ${yyyy}
   then
     day_in_year=365
   else
     day_in_year=366
   fi
   total=`expr $total + $day_in_year`
done

leap=`expr ${yyyy} \/ 4`
leap=`expr $leap \* 4`
l100=`expr ${yyyy} \/ 100`
l100=`expr $l100 \* 100`
if test ${yyyy} -eq $l100
then
   leap=`expr ${yyyy} \/ 400`
   leap=`expr $leap \* 400`
fi
if test ${yyyy} -eq $leap
then
   if test $total -le 31
   then
      mm=1
      dd=$total
   elif test $total -le 60
   then
      mm=2
      dd=`expr $total - 31`
   elif test $total -le 91
   then
      mm=3
      dd=`expr $total - 60`
   elif test $total -le 121
   then
      mm=4
      dd=`expr $total - 91`
   elif test $total -le 152
   then
      mm=5
      dd=`expr $total - 121`
   elif test $total -le 182
   then
      mm=6
      dd=`expr $total - 152`
   elif test $total -le 213
   then
      mm=7
      dd=`expr $total - 182`
   elif test $total -le 244
   then
      mm=8
      dd=`expr $total - 213`
   elif test $total -le 274
   then
      mm=9
      dd=`expr $total - 244`
   elif test $total -le 305
   then
      mm=10
      dd=`expr $total - 274`
   elif test $total -le 335
   then
      mm=11
      dd=`expr $total - 305`
   else
      mm=12
      dd=`expr $total - 335`
   fi
else
   if test $total -le 31
   then
      mm=1
      dd=$total
   elif test $total -le 59
   then
      mm=2
      dd=`expr $total - 31`
   elif test $total -le 90
   then
      mm=3
      dd=`expr $total - 59`
   elif test $total -le 120
   then
      mm=4
      dd=`expr $total - 90`
   elif test $total -le 151
   then
      mm=5
      dd=`expr $total - 120`
   elif test $total -le 181
   then
      mm=6
      dd=`expr $total - 151`
   elif test $total -le 212
   then
      mm=7
      dd=`expr $total - 181`
   elif test $total -le 243
   then
      mm=8
      dd=`expr $total - 212`
   elif test $total -le 273
   then
      mm=9
      dd=`expr $total - 243`
   elif test $total -le 304
   then
      mm=10
      dd=`expr $total - 273`
   elif test $total -le 334
   then
      mm=11
      dd=`expr $total - 304`
   else
      mm=12
      dd=`expr $total - 334`
   fi
fi

yyyy=`expr ${yyyy} \* 1`
if test ${yyyy} -lt 10
then
   yyyy="000"${yyyy}
elif test ${yyyy} -lt 100
then
   yyyy="00"${yyyy}
elif test ${yyyy} -lt 1000
then
   yyyy="0"${yyyy}
fi
mm=`expr $mm \* 1`
if test $mm -lt 10
then
   mm="0"${mm}
fi
dd=`expr $dd \* 1`
if test $dd -lt 10
then
   dd="0"${dd}
fi

echo ${yyyy}${mm}${dd}
exit
