#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/cal_yday2date.sh
# 
# NAME
#     cal_yday2date.sh
#
# PURPOSE
# 		Calulate the Calendar date given the Day of the Year
#
# DESCRIPTION
# 		This script calulates the Calendar date given the Day of the Year
#
# USAGE
#     cal_num_of_days.sh $yyyy $yday
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

# Calculate the Calendar date given the Day of the Year
# 2013.11.20 Hai-Tien Lee
# Reference:
# A. Pouplier, 1987: Letter to Jean Meeus, 1978 April 10.

# Passing in 4-digit year and day of the year
yyyy=$1
yday=$2

# echo Year $yyyy day $yday

# Determine whether it is a leap year (k=1)
if [ `echo "$yyyy % 4" | bc` -eq 0 ]
then
	if [ `echo "$yyyy % 100" | bc` -eq 0 ] && [ `echo "$yyyy % 400" | bc` -ne 0 ]
	then
		k=2
# 		echo $yyyy is not a leap
	else
		k=1
# 		echo $yyyy is a leap
	fi
else
	k=2
# 	echo $yyyy is not a leap
fi

if [ $yday -lt 32 ]
then
	mm=1
else
	mm=`echo "scale=5; 9 * ( $k + $yday ) / 275 + 0.98" | bc | cut -d. -f1` 
fi
# 	echo Month= $mm

# dd=n-int((275*mm)/9.) + k*int((mm+9.)/12.) + 30.
a1=`echo "scale=5; (275*$mm)/9" | bc | cut -d. -f1 `
a2=`echo "scale=5; ($mm+9)/12 " | bc `
flag_less_than_one=`echo "scale=5; ($mm+9)/12 < 1." | bc `

if [ ${flag_less_than_one} -eq 1 ]
then
	a2=0
else
	a2=`echo "scale=5; ($mm+9)/12 " | bc | cut -d. -f1 `
fi

mday=`echo "scale=1; $yday - $a1 + $k * $a2 + 30" | bc `

# Return date in yyyymmdd format
printf "%4.4i%2.2i%2.2i\n"  $yyyy $mm $mday


exit
