#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/define_pred_version.sh
# 
# NAME
#     define_pred_version.sh
#
# PURPOSE
# 		Define source of the prediction coefficients file used in McMillin calibration algorothm
#
# DESCRIPTION
# 		This script defins source of the prediction coefficients file used in McMillin 
#     calibration algorothm
#
# USAGE
#     define_pred_version.sh
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
#  	pred_cali_oper.dat file is created in each Data_static/cali_data/Nxx directory 
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################


# McMillin's HIRS Radiance Algorithm requires the prediction coefficients for instrument temperatures
# Here the version of the coefficients files are defined.
# The OLR_retrieval.sh scripts will always use "pred_cali_oper.dat".
# This scripts creates symbolic links to define which version of pred_cali data is used.

# 2011.3.27
# current set up
# N05-N12 pred_cali.dat
# N14     pred_cali2.dat
# N15-N21 Pred_cali3.dat

# 2013.11.18
# Add N21 

set -x

src='/Garden/Hai-Tien/OLR_CDR/HIRS_OLR_CDR_Production'
data_static="$src/Data_static/cali_data"

# Using Version 1 (use all 8 instrument temperatures, derived by McMillin for CDR2.0)
cp $data_static/N05/N05_pred_cali.dat $data_static/N05/pred_cali_oper.dat
cp $data_static/N06/N06_pred_cali.dat $data_static/N06/pred_cali_oper.dat
cp $data_static/N07/N07_pred_cali.dat $data_static/N07/pred_cali_oper.dat
cp $data_static/N08/N08_pred_cali.dat $data_static/N08/pred_cali_oper.dat
cp $data_static/N09/N09_pred_cali.dat $data_static/N09/pred_cali_oper.dat
cp $data_static/N10/N10_pred_cali.dat $data_static/N10/pred_cali_oper.dat
cp $data_static/N11/N11_pred_cali.dat $data_static/N11/pred_cali_oper.dat
cp $data_static/N12/N12_pred_cali.dat $data_static/N12/pred_cali_oper.dat

# Using Version 2 (use 3 instrument temperatures, derived by Lee for CDR2.1)
cp $data_static/N14/N14_pred_cali2.dat $data_static/N14/pred_cali_oper.dat

# Using Version 3 (use 7 instrument temperatures, derived by Lee for CDR2.2)
cp $data_static/N15/N15_pred_cali3.dat $data_static/N15/pred_cali_oper.dat
cp $data_static/N16/N16_pred_cali3.dat $data_static/N16/pred_cali_oper.dat
cp $data_static/N17/N17_pred_cali3.dat $data_static/N17/pred_cali_oper.dat
cp $data_static/N18/N18_pred_cali3.dat $data_static/N18/pred_cali_oper.dat
cp $data_static/N19/N19_pred_cali3.dat $data_static/N19/pred_cali_oper.dat
cp $data_static/N20/N20_pred_cali3.dat $data_static/N20/pred_cali_oper.dat
cp $data_static/N21/N21_pred_cali3.dat $data_static/N21/pred_cali_oper.dat

exit
