#!/bin/sh

##########################################################################################
#@***h* Daily OLR CDR/distribute_codes.sh
# 
# NAME
#     distribute_codes.sh
#
# PURPOSE
# 		Distribute common codes to Code directory for each satellite
#
# DESCRIPTION
# 		This script distributes OLR retrieval codes to Code directory for each satellite
#
# USAGE
#     distribute_codes.sh $home
#     $home is the production home directory
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

# Distribute common codes to Code directory for each satellite
#     2011-03-30 Hai-Tien Lee
#     2013-11-20  Hai-Tien Lee, Add N21

# Usage: distribute_codes.sh "Production_Home_directory"

if [ $# -eq 0 ]
then
echo Error: direcotry not provided.
echo Usage: distribute_codes.sh "Production_Home_directory"
exit
fi

# home='OLR_CDR/HIRS_OLR_CDR_Production'
home=$1

code=$home/Codes

group='All HIRS2 HIRS2_1995 HIRS34'

satids_All="N05 N06 N07 N08 N09 N10 N11 N12 N14 N15 N16 N17 N18 N19 N20 N21"
satids_HIRS2='N05 N06 N07 N08 N09 N10 N11 N12 N14'
satids_HIRS2_1995='N11 N12 N14'
satids_HIRS3='N15 N16 N17'
satids_HIRS4='N18 N19 N20 N21'
satids_HIRS34='N15 N16 N17 N18 N19 N20 N21'

common_All=`ls $code/common/All`
common_HIRS2=`ls $code/common/HIRS2`
common_HIRS2_1995=`ls $code/common/HIRS2_1995`
common_HIRS3=`ls $code/common/HIRS3`
common_HIRS4=`ls $code/common/HIRS4`
common_HIRS34=`ls $code/common/HIRS34`

# make directories
for sat in $satids_All
do
	mkdir -p $code/OLR_retrieval/$sat
done


# Copy codes respectively
for prg in $common_All
do
	for satid in $satids_All
	do
		cp -p $code/common/All/$prg $code/OLR_retrieval/$satid/
	done
done

for prg in $common_HIRS2
do
	for satid in $satids_HIRS2
	do
		cp -p $code/common/HIRS2/$prg $code/OLR_retrieval/$satid/
	done
done

for prg in $common_HIRS2_1995
do
	for satid in $satids_HIRS2_1995
	do
		cp -p $code/common/HIRS2_1995/$prg $code/OLR_retrieval/$satid/
	done
done

for prg in $common_HIRS3
do
	for satid in $satids_HIRS3
	do
		cp -p $code/common/HIRS3/$prg $code/OLR_retrieval/$satid/
	done
done

for prg in $common_HIRS4
do
	for satid in $satids_HIRS4
	do
		cp -p $code/common/HIRS4/$prg $code/OLR_retrieval/$satid/
	done
done

for prg in $common_HIRS34
do
	for satid in $satids_HIRS34
	do
		cp -p $code/common/HIRS34/$prg $code/OLR_retrieval/$satid/
	done
done


exit
