﻿#!/usr/bin/perl

##########################################################################################
#@***h* Daily OLR CDR/scan_files.pl
# 
# NAME
#     scan_files.pl
#
# PURPOSE
# 		Prepare input control for netCDF packing
#
# DESCRIPTION
# 		This script scans the daily OLR files and prepare input control files
#
# USAGE
#     perl scan_files.pl $yyyy $dailydir > OLR_CDR_ascii_input.dat
#
# AUTHOR
#   Hai-Tien Lee
# 
# COPYRIGHT	
#   THIS SOFTWARE AND ITS DOCUMENTATION ARE CONSIDERED TO BE IN THE PUBLIC 
#   DOMAIN AND THUS ARE AVAILABLE FOR UNRESTRICTED PUBLIC USE. THEY ARE 
#   FURNISHED "AS IS." THE AUTHORS, THE UNITED STATES GOVERNMENT, ITS 
#   INSTRUMENTALITIES, OFFICERS, EMPLOYEES, AND AGENTS MAKE NO WARRANTY, 
#   EXPRESS OR IMPLIED, AS TO THE USEFULNESS OF THE SOFTWARE AND 
#   DOCUMENTATION FOR ANY PURPOSE. THEY ASSUME NO RESPONSIBILITY (1) FOR 
#   THE USE OF THE SOFTWARE AND DOCUMENTATION; OR (2) TO PROVIDE TECHNICAL 
#   SUPPORT TO USERS.
# 
# INPUT
# 
# OUTPUT
#    OLR_CDR_ascii_input.dat
# 
# HISTORY
#     2014-06-01   Hai-Tien Lee for NCDC Daily OLR CDR Production
#
#@*****
#########################################################################################

my $filename = "Daily/2000/OLR_daily_2000d365.dat";
my $dailydir = "Daily";
my $year = 2000;
my $month;
my $day;
my $jday;
my $total_days;
my @days_in_month = (31, 28, 31, 30, 31, 30, 31, 31, 30, 31, 30, 31);
my $exist;

my ($year) = $ARGV[0];
my $dailydir = $ARGV[1];

if (not defined $year) {
   die "Need to enter year as argument: > command year\n";
}

$leap = &is_leap($year);
if ( $leap == 1) {
   $total_days = 366;
   $days_in_month[1] = 29;
} else {
   $total_days = 365;
}
$month = 1;
$day = 1;
for ( $jday = 1; $jday <= $total_days; $jday++) {
   $filename = sprintf("%s/%4.4d/OLR_daily_%4.4dd%3.3d.dat",$dailydir,$year,$year,$jday);
   $exist = &f_exist($filename);
   if ($day > $days_in_month[$month-1]) {
      $day = $day - $days_in_month[$month-1];
      $month++;
   }
   printf("%s\n",$filename);
   printf("%4.4d\n",$year);
   printf("%2.2d\n",$month);
   printf("%2.2d\n",$day);
   if ( $exist != 0 ) {
      printf("%d\n",0);
   } else {
      printf("%d\n",1);
   }

   $day++;
}

exit 0;

sub f_exist {
   my ($filename) = @_;

   if ((stat($filename))[7] > 0) {
      return 1;
   } else {
      return 0;
   }
}

sub is_leap{
   my ( $year ) = @_;

   local ($leap = 0);

   if (($year % 4) == 0) {
     if (($year % 100 ) == 0) {
        if (($year % 400 ) == 0) {
           $leap = 1;
        } else {
           $leap = 0;
        }
     } else {
        $leap = 1;
     }
   } else {
      $leap = 0;
   }

   return($leap);

}
